@@ -25,6 +25,7 @@ class StructChildrenProvider(AbstractChildrenProvider):
         child_root = get_root_value(child)
         child_root.SetFormat(self.format_spec & eFormatInheritedFlagsMask)
 
+        ItemExpression.update_struct_child_item_expression(child, self.value)
         update_value_dynamic_state(child)
 
         return child
@@ -50,7 +51,7 @@ class PointerChildrenProvider(AbstractChildrenProvider):
     def __init__(self, value_non_synth: lldb.SBValue):
         # no need to manipulate formats here
         # pointees inherit all formatting from pointer parents (?)
-        self.pointee = value_non_synth.Dereference()
+        self.pointee = ItemExpression.dereference(value_non_synth)
 
     def num_children(self) -> int:
         if not self.pointee.IsValid():
@@ -214,15 +215,7 @@ class CharVisDescriptor(AbstractVisDescriptor):
 
 
 def _cast_value_to_array(value_non_synth: lldb.SBValue, is_array: bool, fmt: int, array_size: int):
-    val_type = value_non_synth.GetType()
-    if is_array:
-        elem_type = val_type.GetArrayElementType()
-        value_non_synth = value_non_synth.AddressOf()
-    else:
-        elem_type = val_type.GetPointeeType()
-
-    upd_val_type = elem_type.GetArrayType(array_size).GetPointerType()
-    new_val = value_non_synth.Cast(upd_val_type).Dereference()
+    new_val = ItemExpression.cast_value_to_array(value_non_synth, is_array, array_size)
 
     # reset format as array flag
     new_val_fmt = fmt & ~eFormatAsArray
@@ -420,13 +413,13 @@ class GenericPointerVisDescriptor(AbstractVisDescriptor):
         if stream.level >= g_max_recursion_level:
             stream.output('{...}')
         elif self.pointee_expands:
-            stream.output_object(value_non_synth.Dereference().GetNonSyntheticValue())
+            stream.output_object(ItemExpression.dereference(value_non_synth).GetNonSyntheticValue())
         else:
             stream.output('{')
             if stream.length > get_max_string_length():
                 stream.output("...")
             else:
-                stream.output_object(value_non_synth.Dereference().GetNonSyntheticValue())
+                stream.output_object(ItemExpression.dereference(value_non_synth).GetNonSyntheticValue())
             stream.output('}')
 
     def prepare_children(self, value_non_synth: lldb.SBValue):
@@ -441,8 +434,7 @@ class GenericPointerVisDescriptor(AbstractVisDescriptor):
             return AbstractChildrenProvider()
 
         if self.pointee_expands:
-            pointee = value_non_synth.Dereference()
-            return WrappedChildrenProvider(pointee)
+            return WrappedChildrenProvider(ItemExpression.dereference(value_non_synth))
         return PointerChildrenProvider(value_non_synth)
 
     @staticmethod
@@ -460,10 +452,10 @@ class GenericReferenceVisDescriptor(AbstractVisDescriptor):
         if stream.level >= g_max_recursion_level:
             stream.output('{...}')
         else:
-            stream.output_object(value_non_synth.Dereference().GetNonSyntheticValue())
+            stream.output_object(ItemExpression.dereference(value_non_synth).GetNonSyntheticValue())
 
     def prepare_children(self, value_non_synth: lldb.SBValue):
-        return WrappedChildrenProvider(value_non_synth.Dereference())
+        return WrappedChildrenProvider(ItemExpression.dereference(value_non_synth))
 
 
 class StructVisDescriptor(AbstractVisDescriptor):
